﻿using System;

using Xamarin.Forms;
using System.Collections.Generic;
using Syncfusion.SfChart.XForms;
using System.Diagnostics;
using System.Collections.ObjectModel;
using System.Linq;

namespace SimpleSample
{
    public class SampleChart : ContentPage
    {
        ObservableCollection<ChartDataPoint> DateTimeData { get; set; }
        public SampleChart()
        {
            StackLayout layout = new StackLayout() { Padding = new Thickness(5, 15, 5, 5) };

            DateTimeData = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint(new DateTime(2016, 01, 1, 10, 5, 10), 54),
                new ChartDataPoint(new DateTime(2016, 01, 1, 10, 10, 10), 34),
                new ChartDataPoint(new DateTime(2016, 01, 1, 10, 23, 10), 44),
                new ChartDataPoint(new DateTime(2016, 01, 1, 10, 26, 10), 24),
                new ChartDataPoint(new DateTime(2016, 01, 2, 10, 12, 10), 54),
                new ChartDataPoint(new DateTime(2016, 01, 2, 10, 5, 10), 14),
                new ChartDataPoint(new DateTime(2016, 01, 2, 10, 8, 10), 34),
                new ChartDataPoint(new DateTime(2016, 01, 3, 10, 13, 10), 23),
                new ChartDataPoint(new DateTime(2016, 01, 3, 10, 5, 10), 14),
                new ChartDataPoint(new DateTime(2016, 01, 4, 10, 18, 10), 53),
                new ChartDataPoint(new DateTime(2016, 01, 5, 10, 20, 10), 25),
                new ChartDataPoint(new DateTime(2016, 01, 5, 10, 24, 10), 15),
                new ChartDataPoint(new DateTime(2016, 01, 6, 10, 20, 10), 25),
                new ChartDataPoint(new DateTime(2016, 01, 6, 10, 24, 10), 36),
                new ChartDataPoint(new DateTime(2016, 01, 6, 10, 25, 10), 10),
                new ChartDataPoint(new DateTime(2016, 01, 6, 10, 32, 10), 54),
                new ChartDataPoint(new DateTime(2016, 01, 7, 10, 20, 10), 25),
                new ChartDataPoint(new DateTime(2016, 01, 7, 10, 14, 10), 25)
            };

            var chart = new SfChart();
            chart.VerticalOptions = LayoutOptions.FillAndExpand;
            chart.HorizontalOptions = LayoutOptions.FillAndExpand;

            DateTimeAxis axis = new DateTimeAxis();
            axis.RangePadding = DateTimeRangePadding.Round;
            axis.Interval = 1;
            axis.IntervalType = DateTimeIntervalType.Days;
            axis.LabelStyle.LabelFormat = "yyyy/MMM/dd";
            axis.LabelsIntersectAction = AxisLabelsIntersectAction.MultipleRows;
            chart.PrimaryAxis = axis;

            NumericalAxis numericalAxis = new NumericalAxis();
            chart.SecondaryAxis = numericalAxis;

            chart.Series = GetSeries();

            layout.Children.Add(chart);
            Content = layout;
        }

        private ChartSeriesCollection GetSeries()
        {
            ChartSeriesCollection seriesCollection = new ChartSeriesCollection();
            var sortedDate = DateTimeData.OrderBy(d => d.XValue).ToList();
            DateTime prevDate = (DateTime)(sortedDate[0].XValue);
            DateTime date = (DateTime)(sortedDate[0].XValue);
            bool flag = false;
            int i = 0;
            for (int j = 0; j < sortedDate.Count(); j++)
            {
                DateTime currentDate = (DateTime)(sortedDate[j].XValue);
                if (currentDate.Day == prevDate.Day)
                {
                    if (!flag)
                    {
                        ObservableCollection<ChartDataPoint> data = new ObservableCollection<ChartDataPoint>();
                        data.Add(new ChartDataPoint(date, sortedDate[j].YValue));
                        seriesCollection.Add(new StackingColumnSeries()
                        {
                            ItemsSource = data,
                            DataMarker = new ChartDataMarker()
                        });
                    }
                    else
                    {
                        (seriesCollection[i].ItemsSource as ObservableCollection<ChartDataPoint>)
                                           .Add(new ChartDataPoint(date, sortedDate[j].YValue));
                        i++;
                    }
                    prevDate = (DateTime)sortedDate[j].XValue;
                }
                else
                {
                    date = (DateTime)sortedDate[j].XValue;
                    (seriesCollection[0].ItemsSource as ObservableCollection<ChartDataPoint>)
                                           .Add(new ChartDataPoint(date, sortedDate[j].YValue));
                    prevDate = (DateTime)sortedDate[j].XValue;
                    flag = true;
                    i = 1;
                }
            }
            return seriesCollection;
        }
    }
}
	